# Pan and Compress Sonifications in Directory

"""
This function does the following for each .wav file in the current directory:
1. Applies a smooth panning from left to right over the duration of the file for spatial effect
2. Exports the audio as an OGG file in place of the original WAV to save memory
"""

import os

import numpy as np

from pydub import AudioSegment

from pydub.effects import pan

for item in os.listdir():
    
    if item[-4:] != '.wav':
        
        continue
    
    audio = AudioSegment.from_wav(item)
    
    NUM_OF_SLICES = round(audio.duration_seconds * 20)
    
    slices = np.round(np.linspace(0, len(audio), NUM_OF_SLICES + 1))
    
    pan_vec = np.linspace(-1, 1, NUM_OF_SLICES)
    
    new_audio = AudioSegment.empty()
    
    for i, pan_val in enumerate(pan_vec):
        
        new_audio += pan(audio[slices[i]:slices[i+1]], pan_val)
    
    new_audio.export(item[:-4]+'.ogg', format="ogg")
    
    os.remove(item)
